==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es_AR.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Unknown user" : "Usuario desconocido",
    "New comment …" : "Nuevo comentario ...",
    "Delete comment" : "Borrar comentario",
    "Post" : "Post",
    "Cancel" : "Cancelar",
    "Edit comment" : "Editar comentario",
    "[Deleted user]" : "[Usuario borrado]",
    "No comments yet, start the conversation!" : "No hay comentarios aún, iniciar la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} of {max}",
    "Error occurred while retrieving comment with id {id}" : "Se ha producido un error al recuperar el comentario con id {id}",
    "Error occurred while updating comment with id {id}" : "Se ha producido un error al actualizar el comentario con id {id}",
    "Error occurred while posting comment" : "Se ha producido un error al publicar un comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
    "Comment" : "Comentar",
    "You commented" : "Ud. ha comentado",
    "%1$s commented" : "%1$s comentados",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Ud. ah comentado en %1$s",
    "You commented on {file}" : "Ud. ha comentado en {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> en archivos",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un (now) usuario borrado te ha mencionado en un comentario en “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un (now) usuario borrado the ha mencionado en un comentario en “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te ha mencionado en un comentario en “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} te ha mencionado en un comentario en “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es_AR.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Unknown user" : "Usuario desconocido",
    "New comment …" : "Nuevo comentario ...",
    "Delete comment" : "Borrar comentario",
    "Post" : "Post",
    "Cancel" : "Cancelar",
    "Edit comment" : "Editar comentario",
    "[Deleted user]" : "[Usuario borrado]",
    "No comments yet, start the conversation!" : "No hay comentarios aún, iniciar la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} of {max}",
    "Error occurred while retrieving comment with id {id}" : "Se ha producido un error al recuperar el comentario con id {id}",
    "Error occurred while updating comment with id {id}" : "Se ha producido un error al actualizar el comentario con id {id}",
    "Error occurred while posting comment" : "Se ha producido un error al publicar un comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
    "Comment" : "Comentar",
    "You commented" : "Ud. ha comentado",
    "%1$s commented" : "%1$s comentados",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Ud. ah comentado en %1$s",
    "You commented on {file}" : "Ud. ha comentado en {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> en archivos",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te ha mencionado en un comentario en “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} te ha mencionado en un comentario en “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un (now) usuario borrado te ha mencionado en un comentario en “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un (now) usuario borrado the ha mencionado en un comentario en “{file}”"
},
"nplurals=2; plural=(n != 1);");
